package com.chuanglan.shanyan_sdk_test_demo.view;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.RelativeLayout;

import com.chuanglan.shanyan_sdk.OneKeyLoginManager;
import com.chuanglan.shanyan_sdk.listener.OneKeyLoginListener;
import com.chuanglan.shanyan_sdk.listener.OpenLoginAuthListener;
import com.chuanglan.shanyan_sdk_test_demo.R;
import com.chuanglan.shanyan_sdk_test_demo.utils.AbScreenUtils;
import com.chuanglan.shanyan_sdk_test_demo.utils.ConfigUtils;
import com.chuanglan.shanyan_sdk_test_demo.utils.VideoUtils;

import org.json.JSONObject;

public class VedioActivity extends BaseActivity implements View.OnClickListener {
    private MyVideoView mVideoView;
    private RelativeLayout mLoginRoot;
    private RelativeLayout mLoginPar;
    private Button mLoginBt;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.shanyan_demo_activity_vedio);
        getWindow().addFlags(1024);
        initViews();
        initListener();
        startVideo();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        stopVideo();
    }

    private void initListener() {
        mLoginBt.setOnClickListener(this);
    }

    private void startVideo() {
        VideoUtils.startBgVideo(mVideoView, getApplicationContext(), "android.resource://" + this.getPackageName() + "/" + R.raw.shanyan_demo_test_vedio);
    }

    private void stopVideo() {
        mVideoView.stopPlayback();
    }


    private void initViews() {
        mLoginRoot = findViewById(R.id.shanyan_demo_login_root);
        mLoginPar = findViewById(R.id.shanyan_demo_login_parent);
        mLoginBt = findViewById(R.id.shanyan_demo_login_G);
        mVideoView = new MyVideoView(getApplicationContext());
        RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.MATCH_PARENT, RelativeLayout.LayoutParams.MATCH_PARENT);
        mLoginRoot.addView(mVideoView, 0, layoutParams);
    }

    @Override
    public void onClick(View v) {
        OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getGConfig(getApplicationContext()), null);
        openLoginActivity(VedioActivity.this);
    }

    @Override
    public void openLoginActivity(Activity activity) {
        OneKeyLoginManager.getInstance().openLoginAuth(true, new OpenLoginAuthListener() {
            @Override
            public void getOpenLoginAuthStatus(int i, String s) {
                if (i == 1000) {
                    mLoginPar.setVisibility(View.GONE);
                }
            }
        }, new OneKeyLoginListener() {
            @Override
            public void getOneKeyLoginStatus(int code, String result) {
                mLoginPar.setVisibility(View.VISIBLE);
                try {
                    if (code == 1000) {//获取token成功，请调用自己服务端置换手机号
                        // AbScreenUtils.showToast(getApplicationContext(), "获取token成功");
                        startResultActivity(code, result, System.currentTimeMillis());
                    } else {//获取token失败
                        AbScreenUtils.showToast(getApplicationContext(), new JSONObject(result).optString("innerDesc"));
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }

    private void startResultActivity(int code, String result, long startTime) {
        Intent intent = new Intent(VedioActivity.this, ResultActivity.class);
        intent.putExtra("type", "0");
        intent.putExtra("startTime", startTime);
        intent.putExtra("loginResult", result);
        intent.putExtra("loginCode", code);
        startActivity(intent);
        OneKeyLoginManager.getInstance().finishAuthActivity();
        OneKeyLoginManager.getInstance().removeAllListener();
        finish();
    }
}